@@ -7,7 +7,9 @@ class EvalEventData(BaseModel):
     webhooks: str
     images: Optional[List[Image]]
     evaluation_file: Optional[str]
-    model_name: str
+    last_file: Optional[bool]
+    prediction_model_name: str
+    label_model_name: str
     model_id: str
     model_type: str
     mapping: Optional[Dict[str, Dict[str, str]]]
