@@ -16,7 +16,7 @@ class PreRunEventData(BaseModel):
     imagesfile: Optional[str]
     model_name: str
     base_model_id: Optional[str]
-    include_data: Optional[str]
+    include_data: Optional[List[str]]
     exclude_classes: Optional[List[str]]
     base_dataset_id: Optional[str]
     mapping: Optional[Dict[str, Dict[str, str]]]
