@@ -6,4 +6,4 @@ class TrainingEvalEventData(BaseModel):
     model_id: str
     request_type: str
     request_id: str
-    mapping: Optional[Dict[str, Dict[str, str]]]
+    mapping: Optional[str]
